@@ -8,6 +8,8 @@ Returns true if the variable passed to this function is a boolean.
     EOS
   ) do |arguments|
 
+    function_deprecation([:is_bool, 'This method is deprecated, please use the stdlib validate_legacy function, with Stdlib::Compat::Bool. There is further documentation for validate_legacy function in the README.'])
+
     raise(Puppet::ParseError, "is_bool(): Wrong number of arguments " +
       "given (#{arguments.size} for 1)") if arguments.size != 1
 
@@ -18,5 +20,3 @@ Returns true if the variable passed to this function is a boolean.
     return result
   end
 end
-
-# vim: set ts=2 sw=2 et :
